from __future__ import division  # Use true division

from django.template.loader import render_to_string

from wagtail.wagtailembeds import embeds


def embed_to_frontend_html(url):
    try:
        embed = embeds.get_embed(url)

        # Work out ratio
        if embed.width and embed.height:
            ratio = str(embed.height / embed.width * 100) + "%"
        else:
            ratio = "0"

        # Render template
        return render_to_string('wagtailembeds/embed_frontend.html', {
            'embed': embed,
            'ratio': ratio,
        })
    except embeds.EmbedException:
        return ''


def embed_to_editor_html(url):
    try:
        embed = embeds.get_embed(url)

        # Render template
        return render_to_string('wagtailembeds/embed_editor.html', {
            'embed': embed,
        })
    except embeds.EmbedException:
        # Could be replaced with a nice error message
        return ''



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailusers', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofile',
            name='approved_notifications',
            field=models.BooleanField(default=True, help_text='Receive notification when your page edit is approved', verbose_name='Approved notifications'),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='rejected_notifications',
            field=models.BooleanField(default=True, help_text='Receive notification when your page edit is rejected', verbose_name='Rejected notifications'),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='submitted_notifications',
            field=models.BooleanField(default=True, help_text='Receive notification when a page is submitted for moderation', verbose_name='Submitted notifications'),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0001_squashed_0016_change_page_url_path_to_text_field'),
        ('tests', '0004_streammodel_richtext'),
    ]

    operations = [
        migrations.CreateModel(
            name='StreamPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, to='wagtailcore.Page', serialize=False, parent_link=True, primary_key=True)),
                ('body', wagtail.wagtailcore.fields.StreamField((('text', wagtail.wagtailcore.blocks.CharBlock()), ('rich_text', wagtail.wagtailcore.blocks.RichTextBlock()), ('image', wagtail.wagtailimages.blocks.ImageChooserBlock())))),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations
import wagtail.wagtailimages.blocks
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0003_streammodel'),
    ]

    operations = [
        migrations.AlterField(
            model_name='streammodel',
            name='body',
            field=wagtail.wagtailcore.fields.StreamField((('text', wagtail.wagtailcore.blocks.CharBlock()), ('rich_text', wagtail.wagtailcore.blocks.RichTextBlock()), ('image', wagtail.wagtailimages.blocks.ImageChooserBlock()))),
            preserve_default=True,
        ),
    ]



from django.core import urlresolvers
from django.conf import settings
from django.conf.urls import include, url
from django.utils.translation import ugettext_lazy as _

from wagtail.wagtailcore import hooks
from wagtail.wagtailadmin.menu import MenuItem

from wagtail.wagtailforms import urls
from wagtail.wagtailforms.models import get_forms_for_user

@hooks.register('register_admin_urls')
def register_admin_urls():
    return [
        url(r'^forms/', include(urls)),
    ]

class FormsMenuItem(MenuItem):
    def is_shown(self, request):
        # show this only if the user has permission to retrieve submissions for at least one form
        return get_forms_for_user(request.user).exists()

@hooks.register('register_admin_menu_item')
def register_forms_menu_item():
    return FormsMenuItem(_('Forms'), urlresolvers.reverse('wagtailforms_index'), name='forms', classnames='icon icon-form', order=700)


@hooks.register('insert_editor_js')
def editor_js():
    return """<script src="%swagtailforms/js/page-editor.js"></script>""" % settings.STATIC_URL



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import wagtail.wagtailcore.fields
import wagtail.wagtailcore.blocks
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0002_add_verbose_names'),
    ]

    operations = [
        migrations.CreateModel(
            name='StreamModel',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('body', wagtail.wagtailcore.fields.StreamField([('text', wagtail.wagtailcore.blocks.CharBlock()), ('image', wagtail.wagtailimages.blocks.ImageChooserBlock())])),
            ],
        ),
    ]



from django.utils.functional import cached_property

from wagtail.wagtailcore.blocks import ChooserBlock

class ImageChooserBlock(ChooserBlock):
    @cached_property
    def target_model(self):
        from wagtail.wagtailimages.models import get_image_model
        return get_image_model()

    @cached_property
    def widget(self):
        from wagtail.wagtailimages.widgets import AdminImageChooser
        return AdminImageChooser

    def render_basic(self, value):
        if value:
            return value.get_rendition('original').img_tag()
        else:
            return ''
